(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     20279,        599]*)
(*NotebookOutlinePosition[     21018,        625]*)
(*  CellTagsIndexPosition[     20974,        621]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Este documento se basa en una aplicaci\[OAcute]n del m\[EAcute]todo de los \
multiplicadors de Lagrange. Las celdas a evaluar aparecen en un color \
diferente al del fondo. Eval\[UAcute]elas para obtener los resultados.  \
\>", "Commentary"],

Cell[TextData[StyleBox["Optimizaci\[OAcute]n de Turbinas \
Hidr\[AAcute]ulicas",
  FontVariations->{"Underline"->True}]], "Subsubtitle"],

Cell[TextData[StyleBox["En una compa\[NTilde]\[IAcute]a opera una central \
hidroel\[EAcute]ctrica. El agua de una presa se lleva por tuber\[IAcute]as a \
la central. La raz\[OAcute]n a la que circula el agua en las tuber\[IAcute]as \
var\[IAcute]a, dependiendo de condiciones externas.\nLa central tiene tres \
turbinas hidroel\[EAcute]ctricas, cada una con un modelo de funci\[OAcute]n \
de potencia que da la cantidad de energ\[IAcute]a el\[EAcute]ctrica generada \
en funci\[OAcute]n de la cantidad de agua que llega a la turbina. El agua \
entrante, a la central, se puede repartir de diferentes maneras a cada \
turbina, de modo que el objetivo es determinar como distribuir el agua entre \
las turbinas para dar la m\[AAcute]xima producci\[OAcute]n total de energ\
\[IAcute]a para cualquier caudal entrante.\nUsando evidencias experimentales \
se determinaron los siguientes modelos cuadr\[AAcute]ticos para la salida de \
potencia de cada turbina, junto con los flujos permisibles de \
operaci\[OAcute]n:",
  FontFamily->"Arial",
  FontSlant->"Italic"]], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(kw1 = \((\(-18.89\) + 0.1277\ q1 - 
              4.08\ 10\^\(-5\)\ q1\^2)\) \((170 - 
              1.6\ 10\^\(-6\)\ qt\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(kw2 = \((\(-24.51\) + 0.1358\ q2 - 
              4.69\ 10\^\(-5\)\ q2\^2)\) \((170 - 
              1.6\ 10\^\(-6\)\ qt\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(kw3 = \((\(-27.02\) + 0.1380\ q3 - 
              3.84\ 10\^\(-5\)\ q3\^2)\) \((170 - 
              1.6\ 10\^\(-6\)\ qt\^2)\);\)\)}], "Input"],

Cell[TextData[{
  StyleBox["En donde, ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["qi",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" = flujo que pasa por la turbina i en pies c\[UAcute]bicos por \
segundo.\n           ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["    ",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["kwi",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" = potencia generada por la turbina i en kilowatts.\n             \
    ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["qt ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["= flujo total que pasa por la central en pies c\[UAcute]bicos por \
segundo.\n           ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["     250 \[LessEqual] q1 \[LessEqual] 1110;  250 \[LessEqual] q2 \
\[LessEqual] 1110;  250 \[LessEqual] q3 \[LessEqual] 1225.",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["\n                \n                ",
    FontSlant->"Italic"],
  "\n",
  StyleBox["1)",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Si se utilizan las tres turbinas, determine, utilizando \
Multiplicadores de Lagrange, que flujo le corresponde a cada turbina de \
manera tal que la producci\[OAcute]n total de energ\[IAcute]a sea \
m\[AAcute]xima.\nLas limitaciones son que los flujos qi deben sumar el flujo \
total entrante qt y, adem\[AAcute]s, deben cumplirse las restricciones de \
dominio.",
    FontFamily->"Arial",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell[TextData[{
  "Primero, se forma la funci\[OAcute]n de Lagrange. Para esto, se tiene en \
cuenta que la producci\[OAcute]n total de energ\[IAcute]a viene dada por ",
  StyleBox["kw1 + kw2 + kw3",
    FontSlant->"Italic"],
  " (funci\[OAcute]n a extremar) sujeta a ",
  StyleBox["qt = q1+q2+q3",
    FontSlant->"Italic"],
  " y las restricciones de dominio para cada ",
  StyleBox["qi",
    FontSlant->"Italic"],
  ".\nLuego, se hallan los puntos cr\[IAcute]ticos. En este paso, hay que \
considerar las limitaciones de dominio establecidas.\n\nA \
continuaci\[OAcute]n, se define la funci\[OAcute]n de Lagrange y se la deriva \
respecto de sus variables (",
  StyleBox["q1, q2, q3 ",
    FontSlant->"Italic"],
  "y",
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[Lambda]",
  ")."
}], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(F = 
        kw1 + kw2 + 
          kw3 + \[Lambda]\ \((qt - q1 - q2 - 
                q3)\);\)\), "\[IndentingNewLine]", 
    \(\[PartialD]\_q1\ F \[Equal] 0\), "\[IndentingNewLine]", 
    \(\[PartialD]\_q2\ F \[Equal] 0\), "\[IndentingNewLine]", 
    \(\[PartialD]\_q3\ F \[Equal] 0\), "\[IndentingNewLine]", 
    \(\[PartialD]\_\[Lambda]\ F \[Equal] 0\)}], "Input"],

Cell[TextData[{
  "De las 2 primeras ecuaciones se obtiene ",
  StyleBox["q1",
    FontSlant->"Italic"],
  " en funci\[OAcute]n de ",
  StyleBox["q2",
    FontSlant->"Italic"],
  "; y, de la 2da y 3ra ecuaci\[OAcute]n se obtiene ",
  StyleBox["q3",
    FontSlant->"Italic"],
  " en funci\[OAcute]n de ",
  StyleBox["q2",
    FontSlant->"Italic"],
  ". Luego, se sustituye ",
  StyleBox["q1",
    FontSlant->"Italic"],
  " y ",
  StyleBox["q3",
    FontSlant->"Italic"],
  " en la cuarta ecuaci\[OAcute]n; para, as\[IAcute], obtener ",
  StyleBox["q2",
    FontSlant->"Italic"],
  " en funci\[OAcute]n de ",
  StyleBox["qt",
    FontSlant->"Italic"],
  ". Finalmente, se sustituye ",
  StyleBox["q2",
    FontSlant->"Italic"],
  " en ",
  StyleBox["q1",
    FontSlant->"Italic"],
  " y en ",
  StyleBox["q3",
    FontSlant->"Italic"],
  ". El resutado es el siguiente:"
}], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(q1 = \(-75.18\) + 0.3410\ qt;\)\), "\[IndentingNewLine]", 
    \(\(q2 = 20.95 + 0.2967\ qt;\)\), "\[IndentingNewLine]", 
    \(\(q3 = 54.23 + 0.3623\ qt;\)\)}], "Input"],

Cell[TextData[{
  StyleBox["2)",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" \[DownQuestion]Para qu\[EAcute] valores de qt es v\[AAcute]lido \
el resultado anterior?\n",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  "\nEn base a la restricci\[OAcute]n de ",
  StyleBox["q2",
    FontSlant->"Italic"],
  ", se halla el flujo m\[IAcute]nimo total (",
  StyleBox["qt",
    FontSlant->"Italic"],
  " m\[IAcute]nimo) y m\[AAcute]ximo total (",
  StyleBox["qt",
    FontSlant->"Italic"],
  " m\[AAcute]ximo) permisible para el funcionamiento de la turbina 2. De la \
misma manera se procede con ",
  StyleBox["q1",
    FontSlant->"Italic"],
  " y ",
  StyleBox["q3",
    FontSlant->"Italic"],
  ". El valor m\[IAcute]nimo de ",
  StyleBox["qt",
    FontSlant->"Italic"],
  " consistente con el funcionamiento de las 3 turbinas es 953.3; mientras \
que, el valor m\[AAcute]ximo de ",
  StyleBox["qt",
    FontSlant->"Italic"],
  " aceptable es 3232. Por lo tanto, ",
  StyleBox["953,3 \[LessEqual] qt \[LessEqual] 3232",
    FontSlant->"Italic"],
  "."
}], "Text",
  TextJustification->1],

Cell[TextData[{
  StyleBox["3)",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Para un flujo de entrada de 2500 ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)],
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["/s, determine la distribuci\[OAcute]n a las turbinas y verifique \
(intentando con algunas distribuciones cercanas) que el resultado obtenido \
por el m\[EAcute]todo de los multiplicadores de Lagrange es m\[AAcute]ximo.",
    FontFamily->"Arial",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(qt = 2500;\)\), "\[IndentingNewLine]", 
    \(q1\), "\[IndentingNewLine]", 
    \(q2\), "\[IndentingNewLine]", 
    \(q3\), "\[IndentingNewLine]", 
    \(kw1\), "\[IndentingNewLine]", 
    \(kw2\), "\[IndentingNewLine]", 
    \(kw3\), "\[IndentingNewLine]", 
    \(kwt = kw1 + kw2 + kw3\)}], "Input"],

Cell[TextData[{
  StyleBox["4)",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Hasta ahora supusimos que las tres turbinas est\[AAcute]n \
operando.\n\[DownQuestion]Es posible, en algunas situaciones, producir m\
\[AAcute]s energ\[IAcute]a usando s\[OAcute]lo una turbina?\nHaga una gr\
\[AAcute]fica de las tres funciones de potencia y \[UAcute]sela para ayudarse \
a determinar si un flujo entrante de 1000 ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)],
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["/s debe distribuirse en las tres turbinas o llevarse s\[OAcute]lo \
a una. Si se lo lleva s\[OAcute]lo a una, \[DownQuestion]cu\[AAcute]l de las \
turbinas debe ser?\n\[DownQuestion]Qu\[EAcute] sucede si el flujo es de 600 ",
    
    FontFamily->"Arial",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)],
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["/s? ",
    FontFamily->"Arial",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell["\<\
Para empezar, se grafican las curvas de potencia. Estas pueden observarse m\
\[AAcute]s abajo, luego del siguiente c\[OAcute]digo. \
\>", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(Clear[q1, q2, q3, qt]\), "\[IndentingNewLine]", 
    \(\(gr\[AAcute]ficodepotencia1 = 
        Plot[kw1 /. qt \[Rule] 1000, {q1, 250, 1110}, 
          PlotStyle \[Rule] {RGBColor[1, 0, 0], Thickness[0.007], 
              Dashing[{0.01}]}, \[IndentingNewLine]FrameLabel \[Rule] \
{"\<Caudal\>", "\<Potencia 1\>", "\<\>", "\<\>"}, 
          GridLines \[Rule] Automatic, 
          Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(gr\[AAcute]ficodepotencia2 = 
        Plot[kw2 /. qt \[Rule] 1000, {q2, 250, 1110}, 
          PlotStyle \[Rule] {RGBColor[0, 1, 0], Thickness[0.007], 
              Dashing[{0.07}]}, \[IndentingNewLine]FrameLabel \[Rule] \
{"\<Caudal\>", "\<Potencia 2\>", "\<\>", "\<\>"}, 
          GridLines \[Rule] Automatic, 
          Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(gr\[AAcute]ficodepotencia3 = 
        Plot[kw3 /. qt \[Rule] 1000, {q3, 250, 1225}, 
          PlotStyle \[Rule] {RGBColor[0, 0, 1], Thickness[0.007], 
              Dashing[{0}]}, \[IndentingNewLine]FrameLabel \[Rule] {"\<Caudal\
\>", "\<Potencia 3\>", "\<\>", "\<\>"}, GridLines \[Rule] Automatic, 
          Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr\[AAcute]ficodepotencia1, gr\[AAcute]ficodepotencia2, 
        gr\[AAcute]ficodepotencia3, 
        FrameLabel \[Rule] {"\<Caudal\>", "\<Potencia\>", "\<\>", "\<\>"}];\)\
\)}], "Input"],

Cell["\<\
Donde, la curva con trazo continuo (azul) corresponde a la turbina 3; la \
curva con trazo entrecortado largo (verde) corresponde a la turbina 2 y la \
curva con entrecortado corto (rojo) corresponde a la turbina 1.\
\>", "Text",
  TextJustification->1],

Cell[TextData[{
  "En este gr\[AAcute]fico puede verse que para ",
  StyleBox["qt = 1000",
    FontSlant->"Italic"],
  ", la turbina 3 es la que entrega m\[AAcute]s potencia. Al evaluar ",
  StyleBox["kw3",
    FontSlant->"Italic"],
  " con ",
  StyleBox["q3 = qt = 1000",
    FontSlant->"Italic"],
  ", se tiene:"
}], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(q3 = \(qt = 1000\);\)\), "\[IndentingNewLine]", 
    \(kw3\)}], "Input"],

Cell["\<\
Si, por el contrario, se tienen las 3 turbinas funcionando, las \
distribuciones, a cada una, ser\[IAcute]an:\
\>", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(qt = 1000;\)\), "\[IndentingNewLine]", 
    \(q1 = \(-75.18\) + 0.3410\ qt\), "\[IndentingNewLine]", 
    \(q2 = 20.95 + 0.2967\ qt\), "\[IndentingNewLine]", 
    \(q3 = 54.23 + 0.3623\ qt\)}], "Input"],

Cell["\<\
Y, la energ\[IAcute]a total producida ser\[IAcute]a:\
\>", "Text",
  TextJustification->1],

Cell[BoxData[
    \(kwt = kw1 + kw2 + kw3\)], "Input"],

Cell[TextData[{
  "Por lo tanto, ser\[IAcute]a conveniente que funcionara s\[OAcute]lo la \
turbina 3.\nEn cambio, para un caudal de 600 ",
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)]],
  "/s, tambi\[EAcute]n, deber\[IAcute]a operar s\[OAcute]lo la turbina 3; ya \
que es la \[UAcute]nica capaz de funcionar con un caudal inferior a 600 ",
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)]],
  "/s. "
}], "Text",
  TextJustification->1],

Cell[TextData[{
  StyleBox["5)",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Quiz\[AAcute] para algunos niveles de flujo ser\[IAcute]a \
conveniente usar dos turbinas. Si el flujo entrante es de 1500 ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)],
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["/s, \[DownQuestion]es m\[AAcute]s eficiente usar dos turbinas que \
usar tres? De ser as\[IAcute], \[DownQuestion]cu\[AAcute]les dos turbinas \
recomendar\[IAcute]a usar?",
    FontFamily->"Arial",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell["Usando las tres turbinas, la potencia total entregada es:", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(qt = 1500;\)\), "\[IndentingNewLine]", 
    \(\(q1 = \(-75.18\) + 0.3410\ qt;\)\), "\[IndentingNewLine]", 
    \(\(q2 = 20.95 + 0.2967\ qt;\)\), "\[IndentingNewLine]", 
    \(\(q3 = 54.23 + 0.3623\ qt;\)\), "\[IndentingNewLine]", 
    \(kwt = kw1 + kw2 + kw3\)}], "Input"],

Cell["\<\
Si en cambio, el flujo entrante se lo deriva a las turbinas 1 y 2; \
optimizando, mediante el m\[EAcute]todo de los multiplicadores de Lagrange, \
se tiene:\
\>", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(qt = 1500;\)\), "\[IndentingNewLine]", 
    \(\(\(Clear[q1, q2, q3]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(F1 = 
        kw1 + kw2 + \[Lambda]\ \((qt - q1 - 
                q2)\);\)\), "\[IndentingNewLine]", 
    \(Solve[{\[PartialD]\_q1\ F1 \[Equal] 0, \[PartialD]\_q2\ F1 \[Equal] 
          0, \[PartialD]\_\[Lambda]\ F1 \[Equal] 0}, {q1, 
        q2, \[Lambda]}]\)}], "Input"],

Cell[TextData[{
  "Reemplazando ",
  StyleBox["q1",
    FontSlant->"Italic"],
  " y ",
  StyleBox["q2",
    FontSlant->"Italic"],
  " en ",
  StyleBox["kw1",
    FontSlant->"Italic"],
  " y ",
  StyleBox["kw2",
    FontSlant->"Italic"],
  ", respectivamente, la potencia total entregada es de:"
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(kw1 + kw2 /. {q1 \[Rule] 756.0, q2 \[Rule] 744.0}\)], "Input"],

Cell["\<\
Si el flujo entrante se lo deriva a las turbinas 1 y 3; procediendo de igual \
manera que en el paso anterior, se tiene:\
\>", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(F2 = 
        kw2 + kw3 + \[Lambda]\ \((qt - q2 - 
                q3)\);\)\), "\[IndentingNewLine]", 
    \(Solve[{\[PartialD]\_q2\ F2 \[Equal] 0, \[PartialD]\_q3\ F2 \[Equal] 
          0, \[PartialD]\_\[Lambda]\ F2 \[Equal] 0}, {q2, 
        q3, \[Lambda]}]\)}], "Input"],

Cell[TextData[{
  "Reemplazando ",
  StyleBox["q2",
    FontSlant->"Italic"],
  " y ",
  StyleBox["q3",
    FontSlant->"Italic"],
  " en ",
  StyleBox["kw2",
    FontSlant->"Italic"],
  " y ",
  StyleBox["kw3",
    FontSlant->"Italic"],
  ", respectivamente, la potencia total entregada, por las turbinas 2 y 3, es \
de:"
}], "Text",
  TextJustification->1],

Cell[BoxData[
    \(kw2 + kw3 /. {q2 \[Rule] 662.4, q3 \[Rule] 837.6}\)], "Input"],

Cell["\<\
Por \[UAcute]ltimo, se procede de igual manera para con las turbinas 1 y 3. \
\
\>", "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(F3 = 
        kw1 + kw3 + \[Lambda]\ \((qt - q1 - 
                q3)\);\)\), "\[IndentingNewLine]", 
    \(Solve[{\[PartialD]\_q1\ F3 \[Equal] 0, \[PartialD]\_q3\ F3 \[Equal] 
          0, \[PartialD]\_\[Lambda]\ F3 \[Equal] 0}, {q1, 
        q3, \[Lambda]}]\)}], "Input"],

Cell[BoxData[
    \(kw1 + kw3 /. {q3 \[Rule] 662.2, q1 \[Rule] 837.8}\)], "Input"],

Cell[TextData[{
  "De los resultados anteriores, se deduce que, para un flujo de 1500 ",
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)]],
  "/s, es conveniente que funcionen las turbinas 1 y 3, con los flujos \
establecidos."
}], "Text",
  TextJustification->1],

Cell[TextData[{
  StyleBox["6) ",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Si el flujo entrante es de 3400 ",
    FontFamily->"Arial",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)],
    FontFamily->"Arial",
    FontSlant->"Italic"],
  StyleBox["/s, \[DownQuestion]que recomendar\[IAcute]a a la compa\[NTilde]\
\[IAcute]a?",
    FontFamily->"Arial",
    FontSlant->"Italic"]
}], "Text",
  TextJustification->1],

Cell[TextData[{
  "El flujo entrante m\[AAcute]ximo permisible, con las 3 turbinas operando, \
puede ser de 3232 ",
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)]],
  "/s. Como el flujo entrante es de 3400 ",
  Cell[BoxData[
      \(TraditionalForm\`pies\^3\)]],
  "/s; y, seg\[UAcute]n las curvas de potencia, para ese caudal, las turbinas \
1 y 3 son las m\[AAcute]s eficientes, en consecuencia, ser\[AAcute] cuesti\
\[OAcute]n de que \[EAcute]stas funcionen a m\[AAcute]ximo caudal permisible \
y el caudal restante; esto es, 3232 - 1110 - 1225 (m\[AAcute]s lo que falta \
para llegar 3400), vaya a parar a la turbina 2, que es la menos eficiente.\n\
De esta manera, la potencia total entregada es:"
}], "Text",
  TextJustification->1],

Cell[BoxData[{
    \(\(qt = 3232;\)\), "\[IndentingNewLine]", 
    \(\(q1 = 1110;\)\), "\[IndentingNewLine]", 
    \(\(q2 = 3400 - 1110 - 1225;\)\), "\[IndentingNewLine]", 
    \(\(q3 = 1225;\)\), "\[IndentingNewLine]", 
    \(kw1 = \((\(-18.89\) + 0.1277\ q1 - 4.08\ 10\^\(-5\)\ q1\^2)\) \((170 - 
            1.6\ 10\^\(-6\)\ qt\^2)\)\), "\[IndentingNewLine]", 
    \(kw2 = \((\(-24.51\) + 0.1358\ q2 - 4.69\ 10\^\(-5\)\ q2\^2)\) \((170 - 
            1.6\ 10\^\(-6\)\ qt\^2)\)\), "\[IndentingNewLine]", 
    \(kw3 = \((\(-27.02\) + 0.1380\ q3 - 3.84\ 10\^\(-5\)\ q3\^2)\) \((170 - 
            1.6\ 10\^\(-6\)\ qt\^2)\)\), "\[IndentingNewLine]", 
    \(kwt = kw1 + kw2 + kw3\)}], "Input"],

Cell["\<\
------------------------------------------------------------------------------\
-------------------------\
\>", "Text"],

Cell["\<\
Comentarios, sugerencias, dudas? Escriba a am2_utn@yahoo.com.ar\
\>", "Commentary"]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 555}},
WindowSize->{792, 528},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{6, 6},
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 251, 4, 78, "Commentary"],
Cell[2008, 57, 136, 2, 84, "Subsubtitle"],
Cell[2147, 61, 1094, 16, 310, "Text"],
Cell[3244, 79, 496, 9, 101, "Input"],
Cell[3743, 90, 1709, 49, 344, "Text"],
Cell[5455, 141, 820, 23, 218, "Text"],
Cell[6278, 166, 392, 8, 157, "Input"],
Cell[6673, 176, 904, 36, 102, "Text"],
Cell[7580, 214, 192, 3, 100, "Input"],
Cell[7775, 219, 1132, 37, 188, "Text"],
Cell[8910, 258, 631, 18, 111, "Text"],
Cell[9544, 278, 323, 8, 230, "Input"],
Cell[9870, 288, 1111, 30, 235, "Text"],
Cell[10984, 320, 179, 4, 62, "Text"],
Cell[11166, 326, 1405, 25, 594, "Input"],
Cell[12574, 353, 263, 5, 82, "Text"],
Cell[12840, 360, 350, 12, 62, "Text"],
Cell[13193, 374, 95, 2, 74, "Input"],
Cell[13291, 378, 157, 4, 62, "Text"],
Cell[13451, 384, 225, 4, 126, "Input"],
Cell[13679, 390, 100, 3, 42, "Text"],
Cell[13782, 395, 54, 1, 48, "Input"],
Cell[13839, 398, 446, 11, 95, "Text"],
Cell[14288, 411, 672, 19, 89, "Text"],
Cell[14963, 432, 97, 1, 42, "Text"],
Cell[15063, 435, 295, 5, 152, "Input"],
Cell[15361, 442, 204, 5, 62, "Text"],
Cell[15568, 449, 432, 9, 153, "Input"],
Cell[16003, 460, 330, 15, 42, "Text"],
Cell[16336, 477, 82, 1, 48, "Input"],
Cell[16421, 480, 168, 4, 62, "Text"],
Cell[16592, 486, 297, 6, 75, "Input"],
Cell[16892, 494, 357, 16, 62, "Text"],
Cell[17252, 512, 82, 1, 48, "Input"],
Cell[17337, 515, 126, 4, 42, "Text"],
Cell[17466, 521, 297, 6, 75, "Input"],
Cell[17766, 529, 82, 1, 48, "Input"],
Cell[17851, 532, 266, 7, 63, "Text"],
Cell[18120, 541, 487, 17, 45, "Text"],
Cell[18610, 560, 743, 15, 175, "Text"],
Cell[19356, 577, 691, 11, 230, "Input"],
Cell[20050, 590, 129, 3, 42, "Text"],
Cell[20182, 595, 93, 2, 36, "Commentary"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

